==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/TaskOptions.java <==
package io.github.cdklabs.projen;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.447Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.TaskOptions")
@software.amazon.jsii.Jsii.Proxy(TaskOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface TaskOptions extends software.amazon.jsii.JsiiSerializable, io.github.cdklabs.projen.TaskCommonOptions {

    /**
     * (experimental) Shell command to execute as the first command of the task.
     * <p>
     * Default: - add steps using `task.exec(command)` or `task.spawn(subtask)`
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getExec() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link TaskOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link TaskOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<TaskOptions> {
        java.lang.String exec;
        java.lang.String condition;
        java.lang.String cwd;
        java.lang.String description;
        java.util.Map<java.lang.String, java.lang.String> env;
        java.util.List<java.lang.String> requiredEnv;

        /**
         * Sets the value of {@link TaskOptions#getExec}
         * @param exec Shell command to execute as the first command of the task.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder exec(java.lang.String exec) {
            this.exec = exec;
            return this;
        }

        /**
         * Sets the value of {@link TaskOptions#getCondition}
         * @param condition A shell command which determines if the this task should be executed.
         *                  If
         *                  the program exits with a zero exit code, steps will be executed. A non-zero
         *                  code means that task will be skipped.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder condition(java.lang.String condition) {
            this.condition = condition;
            return this;
        }

        /**
         * Sets the value of {@link TaskOptions#getCwd}
         * @param cwd The working directory for all steps in this task (unless overridden by the step).
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder cwd(java.lang.String cwd) {
            this.cwd = cwd;
            return this;
        }

        /**
         * Sets the value of {@link TaskOptions#getDescription}
         * @param description The description of this build command.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder description(java.lang.String description) {
            this.description = description;
            return this;
        }

        /**
         * Sets the value of {@link TaskOptions#getEnv}
         * @param env Defines environment variables for the execution of this task.
         *            Values in this map will be evaluated in a shell, so you can do stuff like <code>$(echo "foo")</code>.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder env(java.util.Map<java.lang.String, java.lang.String> env) {
            this.env = env;
            return this;
        }

        /**
         * Sets the value of {@link TaskOptions#getRequiredEnv}
         * @param requiredEnv A set of environment variables that must be defined in order to execute this task.
         *                    Task execution will fail if one of these is not defined.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder requiredEnv(java.util.List<java.lang.String> requiredEnv) {
            this.requiredEnv = requiredEnv;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link TaskOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public TaskOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link TaskOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements TaskOptions {
        private final java.lang.String exec;
        private final java.lang.String condition;
        private final java.lang.String cwd;
        private final java.lang.String description;
        private final java.util.Map<java.lang.String, java.lang.String> env;
        private final java.util.List<java.lang.String> requiredEnv;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.exec = software.amazon.jsii.Kernel.get(this, "exec", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.condition = software.amazon.jsii.Kernel.get(this, "condition", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.cwd = software.amazon.jsii.Kernel.get(this, "cwd", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.description = software.amazon.jsii.Kernel.get(this, "description", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.env = software.amazon.jsii.Kernel.get(this, "env", software.amazon.jsii.NativeType.mapOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
            this.requiredEnv = software.amazon.jsii.Kernel.get(this, "requiredEnv", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.exec = builder.exec;
            this.condition = builder.condition;
            this.cwd = builder.cwd;
            this.description = builder.description;
            this.env = builder.env;
            this.requiredEnv = builder.requiredEnv;
        }

        @Override
        public final java.lang.String getExec() {
            return this.exec;
        }

        @Override
        public final java.lang.String getCondition() {
            return this.condition;
        }

        @Override
        public final java.lang.String getCwd() {
            return this.cwd;
        }

        @Override
        public final java.lang.String getDescription() {
            return this.description;
        }

        @Override
        public final java.util.Map<java.lang.String, java.lang.String> getEnv() {
            return this.env;
        }

        @Override
        public final java.util.List<java.lang.String> getRequiredEnv() {
            return this.requiredEnv;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getExec() != null) {
                data.set("exec", om.valueToTree(this.getExec()));
            }
            if (this.getCondition() != null) {
                data.set("condition", om.valueToTree(this.getCondition()));
            }
            if (this.getCwd() != null) {
                data.set("cwd", om.valueToTree(this.getCwd()));
            }
            if (this.getDescription() != null) {
                data.set("description", om.valueToTree(this.getDescription()));
            }
            if (this.getEnv() != null) {
                data.set("env", om.valueToTree(this.getEnv()));
            }
            if (this.getRequiredEnv() != null) {
                data.set("requiredEnv", om.valueToTree(this.getRequiredEnv()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.TaskOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            TaskOptions.Jsii$Proxy that = (TaskOptions.Jsii$Proxy) o;

            if (this.exec != null ? !this.exec.equals(that.exec) : that.exec != null) return false;
            if (this.condition != null ? !this.condition.equals(that.condition) : that.condition != null) return false;
            if (this.cwd != null ? !this.cwd.equals(that.cwd) : that.cwd != null) return false;
            if (this.description != null ? !this.description.equals(that.description) : that.description != null) return false;
            if (this.env != null ? !this.env.equals(that.env) : that.env != null) return false;
            return this.requiredEnv != null ? this.requiredEnv.equals(that.requiredEnv) : that.requiredEnv == null;
        }

        @Override
        public final int hashCode() {
            int result = this.exec != null ? this.exec.hashCode() : 0;
            result = 31 * result + (this.condition != null ? this.condition.hashCode() : 0);
            result = 31 * result + (this.cwd != null ? this.cwd.hashCode() : 0);
            result = 31 * result + (this.description != null ? this.description.hashCode() : 0);
            result = 31 * result + (this.env != null ? this.env.hashCode() : 0);
            result = 31 * result + (this.requiredEnv != null ? this.requiredEnv.hashCode() : 0);
            return result;
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/TaskOptions.java <==
package io.github.cdklabs.projen;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.155Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.TaskOptions")
@software.amazon.jsii.Jsii.Proxy(TaskOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface TaskOptions extends software.amazon.jsii.JsiiSerializable, io.github.cdklabs.projen.TaskCommonOptions {

    /**
     * (experimental) Should the provided <code>exec</code> shell command receive fixed args.
     * <p>
     * Default: - no arguments are passed to the step
     * <p>
     * @see <a href="{@link TaskStepOptions.args }">{@link TaskStepOptions.args }</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getArgs() {
        return null;
    }

    /**
     * (experimental) Shell command to execute as the first command of the task.
     * <p>
     * Default: - add steps using `task.exec(command)` or `task.spawn(subtask)`
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getExec() {
        return null;
    }

    /**
     * (experimental) Should the provided <code>exec</code> shell command receive args passed to the task.
     * <p>
     * Default: false
     * <p>
     * @see <a href="{@link TaskStepOptions.receiveArgs }">{@link TaskStepOptions.receiveArgs }</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getReceiveArgs() {
        return null;
    }

    /**
     * (experimental) List of task steps to run.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.List<io.github.cdklabs.projen.TaskStep> getSteps() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link TaskOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link TaskOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<TaskOptions> {
        java.util.List<java.lang.String> args;
        java.lang.String exec;
        java.lang.Boolean receiveArgs;
        java.util.List<io.github.cdklabs.projen.TaskStep> steps;
        java.lang.String condition;
        java.lang.String cwd;
        java.lang.String description;
        java.util.Map<java.lang.String, java.lang.String> env;
        java.util.List<java.lang.String> requiredEnv;

        /**
         * Sets the value of {@link TaskOptions#getArgs}
         * @param args Should the provided <code>exec</code> shell command receive fixed args.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder args(java.util.List<java.lang.String> args) {
            this.args = args;
            return this;
        }

        /**
         * Sets the value of {@link TaskOptions#getExec}
         * @param exec Shell command to execute as the first command of the task.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder exec(java.lang.String exec) {
            this.exec = exec;
            return this;
        }

        /**
         * Sets the value of {@link TaskOptions#getReceiveArgs}
         * @param receiveArgs Should the provided <code>exec</code> shell command receive args passed to the task.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder receiveArgs(java.lang.Boolean receiveArgs) {
            this.receiveArgs = receiveArgs;
            return this;
        }

        /**
         * Sets the value of {@link TaskOptions#getSteps}
         * @param steps List of task steps to run.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @SuppressWarnings("unchecked")
        public Builder steps(java.util.List<? extends io.github.cdklabs.projen.TaskStep> steps) {
            this.steps = (java.util.List<io.github.cdklabs.projen.TaskStep>)steps;
            return this;
        }

        /**
         * Sets the value of {@link TaskOptions#getCondition}
         * @param condition A shell command which determines if the this task should be executed.
         *                  If
         *                  the program exits with a zero exit code, steps will be executed. A non-zero
         *                  code means that task will be skipped.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder condition(java.lang.String condition) {
            this.condition = condition;
            return this;
        }

        /**
         * Sets the value of {@link TaskOptions#getCwd}
         * @param cwd The working directory for all steps in this task (unless overridden by the step).
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder cwd(java.lang.String cwd) {
            this.cwd = cwd;
            return this;
        }

        /**
         * Sets the value of {@link TaskOptions#getDescription}
         * @param description The description of this build command.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder description(java.lang.String description) {
            this.description = description;
            return this;
        }

        /**
         * Sets the value of {@link TaskOptions#getEnv}
         * @param env Defines environment variables for the execution of this task.
         *            Values in this map will be evaluated in a shell, so you can do stuff like <code>$(echo "foo")</code>.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder env(java.util.Map<java.lang.String, java.lang.String> env) {
            this.env = env;
            return this;
        }

        /**
         * Sets the value of {@link TaskOptions#getRequiredEnv}
         * @param requiredEnv A set of environment variables that must be defined in order to execute this task.
         *                    Task execution will fail if one of these is not defined.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder requiredEnv(java.util.List<java.lang.String> requiredEnv) {
            this.requiredEnv = requiredEnv;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link TaskOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public TaskOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link TaskOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements TaskOptions {
        private final java.util.List<java.lang.String> args;
        private final java.lang.String exec;
        private final java.lang.Boolean receiveArgs;
        private final java.util.List<io.github.cdklabs.projen.TaskStep> steps;
        private final java.lang.String condition;
        private final java.lang.String cwd;
        private final java.lang.String description;
        private final java.util.Map<java.lang.String, java.lang.String> env;
        private final java.util.List<java.lang.String> requiredEnv;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.args = software.amazon.jsii.Kernel.get(this, "args", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
            this.exec = software.amazon.jsii.Kernel.get(this, "exec", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.receiveArgs = software.amazon.jsii.Kernel.get(this, "receiveArgs", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.steps = software.amazon.jsii.Kernel.get(this, "steps", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.TaskStep.class)));
            this.condition = software.amazon.jsii.Kernel.get(this, "condition", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.cwd = software.amazon.jsii.Kernel.get(this, "cwd", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.description = software.amazon.jsii.Kernel.get(this, "description", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.env = software.amazon.jsii.Kernel.get(this, "env", software.amazon.jsii.NativeType.mapOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
            this.requiredEnv = software.amazon.jsii.Kernel.get(this, "requiredEnv", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.args = builder.args;
            this.exec = builder.exec;
            this.receiveArgs = builder.receiveArgs;
            this.steps = (java.util.List<io.github.cdklabs.projen.TaskStep>)builder.steps;
            this.condition = builder.condition;
            this.cwd = builder.cwd;
            this.description = builder.description;
            this.env = builder.env;
            this.requiredEnv = builder.requiredEnv;
        }

        @Override
        public final java.util.List<java.lang.String> getArgs() {
            return this.args;
        }

        @Override
        public final java.lang.String getExec() {
            return this.exec;
        }

        @Override
        public final java.lang.Boolean getReceiveArgs() {
            return this.receiveArgs;
        }

        @Override
        public final java.util.List<io.github.cdklabs.projen.TaskStep> getSteps() {
            return this.steps;
        }

        @Override
        public final java.lang.String getCondition() {
            return this.condition;
        }

        @Override
        public final java.lang.String getCwd() {
            return this.cwd;
        }

        @Override
        public final java.lang.String getDescription() {
            return this.description;
        }

        @Override
        public final java.util.Map<java.lang.String, java.lang.String> getEnv() {
            return this.env;
        }

        @Override
        public final java.util.List<java.lang.String> getRequiredEnv() {
            return this.requiredEnv;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getArgs() != null) {
                data.set("args", om.valueToTree(this.getArgs()));
            }
            if (this.getExec() != null) {
                data.set("exec", om.valueToTree(this.getExec()));
            }
            if (this.getReceiveArgs() != null) {
                data.set("receiveArgs", om.valueToTree(this.getReceiveArgs()));
            }
            if (this.getSteps() != null) {
                data.set("steps", om.valueToTree(this.getSteps()));
            }
            if (this.getCondition() != null) {
                data.set("condition", om.valueToTree(this.getCondition()));
            }
            if (this.getCwd() != null) {
                data.set("cwd", om.valueToTree(this.getCwd()));
            }
            if (this.getDescription() != null) {
                data.set("description", om.valueToTree(this.getDescription()));
            }
            if (this.getEnv() != null) {
                data.set("env", om.valueToTree(this.getEnv()));
            }
            if (this.getRequiredEnv() != null) {
                data.set("requiredEnv", om.valueToTree(this.getRequiredEnv()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.TaskOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            TaskOptions.Jsii$Proxy that = (TaskOptions.Jsii$Proxy) o;

            if (this.args != null ? !this.args.equals(that.args) : that.args != null) return false;
            if (this.exec != null ? !this.exec.equals(that.exec) : that.exec != null) return false;
            if (this.receiveArgs != null ? !this.receiveArgs.equals(that.receiveArgs) : that.receiveArgs != null) return false;
            if (this.steps != null ? !this.steps.equals(that.steps) : that.steps != null) return false;
            if (this.condition != null ? !this.condition.equals(that.condition) : that.condition != null) return false;
            if (this.cwd != null ? !this.cwd.equals(that.cwd) : that.cwd != null) return false;
            if (this.description != null ? !this.description.equals(that.description) : that.description != null) return false;
            if (this.env != null ? !this.env.equals(that.env) : that.env != null) return false;
            return this.requiredEnv != null ? this.requiredEnv.equals(that.requiredEnv) : that.requiredEnv == null;
        }

        @Override
        public final int hashCode() {
            int result = this.args != null ? this.args.hashCode() : 0;
            result = 31 * result + (this.exec != null ? this.exec.hashCode() : 0);
            result = 31 * result + (this.receiveArgs != null ? this.receiveArgs.hashCode() : 0);
            result = 31 * result + (this.steps != null ? this.steps.hashCode() : 0);
            result = 31 * result + (this.condition != null ? this.condition.hashCode() : 0);
            result = 31 * result + (this.cwd != null ? this.cwd.hashCode() : 0);
            result = 31 * result + (this.description != null ? this.description.hashCode() : 0);
            result = 31 * result + (this.env != null ? this.env.hashCode() : 0);
            result = 31 * result + (this.requiredEnv != null ? this.requiredEnv.hashCode() : 0);
            return result;
        }
    }
}
